@@ -41,6 +41,7 @@ import sys
 import traceback
 
 from eventlet import spawn_n, monkey_patch
+from eventlet.corolocal import local
 from eventlet.event import Event
 from eventlet.semaphore import Semaphore
 
@@ -50,9 +51,51 @@ from dtest.exceptions import DTestException
 from dtest import test
 
 
+# Default line width
 DEF_LINEWIDTH = 78
 
 
+# Current output for issuing status messages
+_output = local()
+
+
+class _DTestStatus(object):
+    """
+    _DTestStatus
+    ============
+
+    The _DTestStatus class is a stream look-alike class, an instance
+    of which implements the special ``dtest.status`` stream.  Data
+    written to the stream will be passed to the status() method of the
+    current DTestOutput object.  Thread-local data is used to store
+    the current DTestOutput object, so multiple output objects may be
+    safely used simultaneously.
+    """
+
+    def write(self, msg):
+        """
+        Emits ``msg`` as a status message to the current DTestOutput
+        object.  This can be used to notify the user of the status of
+        a test which takes a long time to complete.
+        """
+
+        # Write to the registered output
+        _output.out.status(_output.test, msg)
+
+    def flush(self):
+        """
+        Provided for compatibility with normal output streams.  Does
+        nothing; the DTestOutput object's status() method is assumed
+        to perform a flush after every call.
+        """
+
+        pass
+
+
+# A stream for export
+status = _DTestStatus()
+
+
 class DTestOutput(object):
     """
     DTestOutput
@@ -310,6 +353,33 @@ class DTestOutput(object):
         # Flush the output
         self.output.flush()
 
+    def status(self, dt, message):
+        """
+        Called to emit status messages printed to the dtest.result
+        stream.  The ``dt`` argument will be the test descriptor, and
+        the ``message`` argument will be a message string or, if using
+        the ``print`` statement, bare whitespace.  The default
+        implementation ignores messages consisting of whitespace and
+        writes non-whitespace messages, prefixed with the short name
+        of ``dt``, to the ``self.output`` stream; the output stream
+        will be flushed to ensure the message is emitted.
+        """
+
+        # Ignore messages composed only of whitespace...
+        if message.isspace():
+            return
+
+        # Get the short name of the test...
+        shname = str(dt)
+        if '.' in shname:
+            dummy, shname = shname.rsplit('.', 1)
+
+        # Emit the message
+        print >>self.output, "%s: %s" % (shname, message)
+
+        # Flush the output
+        self.output.flush()
+
 
 class DTestQueue(object):
     """
@@ -409,13 +479,12 @@ class DTestQueue(object):
         for tst in tests:
             self.add_test(tst)
 
-    def run(self):
+    def run(self, debug=False):
         """
         Runs all tests that have been queued up.  Does not return
         until all tests have been run.  Causes test results and
         summary data to be emitted using the ``output`` object
-        registered when the queue was initialized.  Note that if
-        dependency cycles are present, this function may hang.
+        registered when the queue was initialized.
         """
 
         # Can't run an already running queue
@@ -458,7 +527,8 @@ class DTestQueue(object):
         self.waiting = set([dt for dt in self.tests if dt.state != SKIPPED])
 
         # Install the capture proxies...
-        capture.install()
+        if not debug:
+            capture.install()
 
         # Spawn waiting tests
         self._spawn(self.waiting)
@@ -468,7 +538,8 @@ class DTestQueue(object):
             self.th_event.wait()
 
         # OK, uninstall the capture proxies
-        capture.uninstall()
+        if not debug:
+            capture.uninstall()
 
         # Walk through the tests and output the results
         cnt = {
@@ -580,6 +651,11 @@ class DTestQueue(object):
         if self.th_simul > self.th_max:
             self.th_max = self.th_simul
 
+        # Save the output and test relative to this thread, for the
+        # status stream
+        _output.out = self.output
+        _output.test = dt
+
         # Execute the test
         try:
             dt._run(self.output)
@@ -784,7 +860,7 @@ def explore(directory=None, queue=None):
 
 
 def main(directory=None, maxth=None, skip=lambda dt: dt.skip,
-         output=DTestOutput(), dryrun=False, dotpath=None):
+         output=DTestOutput(), dryrun=False, debug=False, dotpath=None):
     """
     Discover tests under ``directory`` (by default, the current
     directory), then run the tests under control of ``maxth``,
@@ -803,7 +879,7 @@ def main(directory=None, maxth=None, skip=lambda dt: dt.skip,
     # Is this a dry run?
     if not dryrun:
         # Nope, execute the tests
-        result = queue.run()
+        result = queue.run(debug=debug)
     else:
         result = True
 
@@ -855,6 +931,11 @@ def optparser(*args, **kwargs):
                   action="store_true", dest="dryrun",
                   help="Performs a dry run.  After discovering all tests, "
                   "the list of tests is printed to standard output.")
+    op.add_option("-D", "--debug",
+                  action="store_true", dest="debug",
+                  help="Enables debugging mode.  Disables output capturing "
+                  "for running tests, causing all output to be emitted "
+                  "immediately.")
     op.add_option("--dot",
                   action="store", type="string", dest="dotpath",
                   help="After running tests, a text representation of the "
@@ -896,6 +977,10 @@ def opts_to_args(options):
     if options.dryrun is True:
         args['dryrun'] = True
 
+    # Are we in debug mode?
+    if options.debug is True:
+        args['debug'] = True
+
     # How about dumping the dependency graph?
     if options.dotpath is not None:
         args['dotpath'] = options.dotpath
