@@ -449,17 +449,21 @@ class DTestBase(object):
             obj = self._class()
 
         # Perform preliminary call
+        pre_status = True
         if self._pre is not None:
             with self._result.accumulate(PRE):
                 do_call(self._pre, obj)
+            if not self._result:
+                pre_status = False
 
         # Execute the test
-        with self._result.accumulate(TEST, self._raises):
-            do_call(self._test, obj)
+        if pre_status:
+            with self._result.accumulate(TEST, self._raises):
+                do_call(self._test, obj)
 
         # Invoke any clean-up that's necessary (regardless of
         # exceptions)
-        if self._post is not None:
+        if pre_status and self._post is not None:
             with self._result.accumulate(POST):
                 do_call(self._post, obj)
 
@@ -690,6 +694,10 @@ def _gettest(func, testcls=DTest):
     if isinstance(func, DTestBase):
         return func
 
+    # If it's a class method or static method, unwrap it
+    if isinstance(func, (classmethod, staticmethod)):
+        func = func.__func__
+
     # Always return None if _dt_nottest is set
     if func is None or (hasattr(func, '_dt_nottest') and func._dt_nottest):
         return None
@@ -737,6 +745,22 @@ def nottest(func):
     return func
 
 
+def isfixture(func):
+    """
+    Decorates a function to indicate that the function is a test
+    fixture, i.e., package- or module-level setUp()/tearDown() or
+    class-level setUpClass()/tearDownClass().  This decorator must be
+    used first on any fixture that one of the other decorators (e.g.,
+    @depends(), @timed()) will be used on.
+    """
+
+    # Make sure func has a DTestFixture associated with it
+    _gettest(func, DTestFixture)
+
+    # Return the function
+    return func
+
+
 def skip(func):
     """
     Decorates a test to indicate that the test should be skipped.
